@@ -6,4 +6,4 @@ from django.contrib.auth import get_user_model
 class GecoUser(models.Model):
     
     user = models.OneToOneField(get_user_model(), on_delete=models.CASCADE)
-    project_dir = models.CharField(max_length=150, unique=True)
\ No newline at end of file
+    user_dir = models.CharField(max_length=150, unique=True)
\ No newline at end of file
