@@ -23,19 +23,19 @@ class GecoRegisterSerializer(RegisterSerializer):
         
         data = request.data
         projects_dir = f'{settings.BASE_DIR}/projects'
-        
+        print(data)
         if not os.path.exists(projects_dir):
             os.mkdir(projects_dir)
 
-        projects_dir = f'{projects_dir}/{data.get("username")}'
-        if not os.path.exists(projects_dir):
-            os.mkdir(projects_dir)
+        user_dir = f'{projects_dir}/{data.get("username")}'
+        if not os.path.exists(user_dir):
+            os.mkdir(user_dir)
 
-        with open(f"{projects_dir}/.htaccess", "w") as htaccess:
+        with open(f"{user_dir}/.htaccess", "w") as htaccess:
             htaccess.write('Header set Access-Control-Allow-Origin "*"\nHeader set Access-Control-Allow-Headers "Access-Control-Allow-Headers, Origin,Accept, X-Requested-With, Content-Type, Access-Control-Request-Method, Access-Control-Request-Headers, range')
 
-
+        print(user_dir)
         user = super().save(request)
-        geco_user = GecoUser(project_dir=projects_dir, user=user)
+        geco_user = GecoUser(user_dir=user_dir, user=user)
         geco_user.save()
         return user
\ No newline at end of file
